[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]

# PyGitHubManager

GitHub desktop version created with Python and PySide6.

## Installation

```bash
$ pip install pygithubmanager
```

## Usage

```python
from pygithubmanager import GitHubManager

GitHubManager()
```

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`githubmanager` was created by DomiTP. It is licensed under the terms of the GNU General Public License v3.0 license.

## Credits

`githubmanager` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).

<!-- MARKDOWN LINKS & IMAGES -->
[stars-shield]: https://img.shields.io/github/stars/DomiTP/GitHubManager.svg?style=for-the-badge
[stars-url]: https://github.com/DomiTP/GitHubManager/stargazers
[issues-shield]: https://img.shields.io/github/issues/DomiTP/GitHubManager.svg?style=for-the-badge
[issues-url]: https://github.com/DomiTP/GitHubManager/issues
[license-shield]: https://img.shields.io/github/license/DomiTP/GitHubManager.svg?style=for-the-badge
[license-url]: https://github.com/DomiTP/GitHubManager/blob/master/LICENSE.md